package com.flyfish.framework.context;

import com.flyfish.framework.utils.Assert;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.BeanInitializationException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

/**
 * spring的上下文
 *
 * @author wangyu
 */
@Component
public class SpringContext implements ApplicationContextAware {

    private ApplicationContext applicationContext;

    private static SpringContext INSTANCE;

    public SpringContext() {
        INSTANCE = this;
    }

    /**
     * 设置上下文
     *
     * @see BeanInitializationException
     */
    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        this.applicationContext = applicationContext;
    }

    /**
     * 通过类获取某个bean
     * 优先获取@Prmary注解的bean
     *
     * @param clazz 类
     * @param <T>   泛型
     * @return 结果
     */
    public static <T> T getBean(Class<T> clazz) {
        return getInstance().applicationContext.getBean(clazz);
    }

    private static SpringContext getInstance() {
        Assert.notNull(INSTANCE, "spring工具类初始化失败！请检查该bean是否注入！");
        return INSTANCE;
    }
}
